<?php

/**
 * @file
 * Entity API integration, classes, controllers, etc.
 */

/**
 * Class DevelSnippetEntity.
 *
 * A common class for Devel snippet entities.
 */
class DevelSnippetEntity extends Entity {

  /**
   * Primary identifier of the snippet.
   *
   * @var int
   */
  public $id = NULL;

  /**
   * The snippet author {users}.uid.
   *
   * @var int
   */
  public $uid = NULL;

  /**
   * Short name of the snippet.
   *
   * @var string
   */
  public $name = '';

  /**
   * Snippet code.
   *
   * @var string
   */
  public $code = '';

  /**
   * The Unix timestamp when the snippet was created.
   *
   * @var int
   */
  public $created = NULL;

  /**
   * The Unix timestamp when the snippet was most recently saved.
   *
   * @var int
   */
  public $changed = NULL;

  /**
   * {@inheritdoc}
   */
  protected function defaultUri() {
    return array(
      'path' => 'devel/php/snippet/manage/' . $this->identifier(),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function save() {
    global $user;
    if (!isset($this->uid)) {
      // @todo Is this the best place to assign author if no provided?
      $this->uid = $user->uid;
    }
    if (!isset($this->created)) {
      $this->created = REQUEST_TIME;
    }
    $this->changed = REQUEST_TIME;
    return parent::save();
  }

}

/**
 * Class DevelSnippetEntityMetadataController.
 *
 * Controller for generating metadata for Devel snippet entity type.
 */
class DevelSnippetEntityMetadataController extends EntityDefaultMetadataController {

  /**
   * {@inheritdoc}
   */
  public function entityPropertyInfo() {
    $info = parent::entityPropertyInfo();
    $properties = &$info[$this->type]['properties'];

    $properties['author'] = array(
      'type' => 'user',
      'label' => t('Author'),
      'description' => t('Author of this Devel Snippet.'),
      'setter callback' => 'entity_property_verbatim_set',
      'schema field' => 'uid',
    );

    $properties['code'] = array(
      'type' => 'text',
      'label' => t('Code'),
      'description' => t('Devel snippet code.'),
      'setter callback' => 'entity_property_verbatim_set',
      'schema field' => 'code',
    );

    $properties['created'] = array(
      'type' => 'date',
      'label' => t('Created'),
      'description' => t('Datetime the Devel snippet was created.'),
      'setter callback' => 'entity_property_verbatim_set',
      'schema field' => 'created',
    );

    $properties['updated'] = array(
      'type' => 'date',
      'label' => t('Updated'),
      'description' => t('Datetime the Devel snippet was most recently updated.'),
      'setter callback' => 'entity_property_verbatim_set',
      'schema field' => 'updated',
    );

    return $info;
  }

}
